@@ -4,12 +4,13 @@
 
 import os
 import tarfile
+import tempfile
 import xml.etree.ElementTree as ET
 import zipfile
 from errno import ENOENT
 from shutil import rmtree
 from tempfile import mkdtemp
-from typing import List, Optional, Dict, Any, IO, Tuple, Union
+from typing import List, Optional, Dict, Any, IO, Tuple
 from xml.etree.ElementTree import Element
 
 import dwca.vendor
@@ -31,6 +32,9 @@ class DwCAReader(object):
     :param extensions_to_ignore: path (relative to the archive root) of extension data files to ignore. This will \
     improve speed and memory usage for large archives. Missing files are silently ignored.
     :type extensions_to_ignore: list
+    :param tmp_dir: temporary directory to use to uncompress the archive (if needed). If not provided, Python default \
+     will be used.
+    :type tmp_dir: str
 
     :raises: :class:`dwca.exceptions.InvalidArchive`
     :raises: :class:`dwca.exceptions.InvalidSimpleArchive`
@@ -76,11 +80,15 @@ class DwCAReader(object):
     def __exit__(self, exc_type, exc_value, exc_traceback):
         self.close()
 
-    def __init__(self, path, extensions_to_ignore=None):
-        # type: (str, List[str]) -> None
+    def __init__(self, path, extensions_to_ignore=None, tmp_dir=None):
+        # type: (str, List[str], str) -> None
         """Open the Darwin Core Archive."""
         if extensions_to_ignore is None:
             extensions_to_ignore = []
+        if tmp_dir is not None:
+            if not os.path.exists(tmp_dir):
+                os.mkdir(tmp_dir)
+            tempfile.tempdir = tmp_dir
 
         #: The path to the Darwin Core Archive file, as passed to the constructor.
         self.archive_path = path  # type: str
